@@ -30,6 +30,7 @@ DEFAULT_LANG_CODE_STR = "en"
 # TODO If no one is using DEFAULT_DATETIME_FORMAT, let's comment it
 # TODO Let's split DEFAULT_DATETIME_FORMAT into two const 1. Displayable to Humans (MMM) 2. Internal (sortable) with %m
 DEFAULT_DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S"
+PRINT_STARS = "*** "
 
 
 def append_if_not_exist(lst: list, item: object) -> None:
@@ -279,6 +280,21 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: (dat
     return is_datetime_in_datetime_range_result
 
 
+# TODO add optional_prefix optional parameter. First check with optional_prefix, if not found, check without it.
+def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True,
+                raise_if_empty: bool = False) -> str:
+    logger.start(object={"key": key, "default": default,
+                         "raise_if_not_found": raise_if_not_found,
+                         "raise_if_empty": raise_if_empty})
+    env_var = os.getenv(key, default)
+    # TODO: "default is None" is always False
+    if ((raise_if_not_found and key not in os.environ and default is None)
+            or (raise_if_empty and not env_var and not default)):
+        raise Exception(f"Environment variable {key} not found - please check your .env file")  # noqa: E501
+    logger.end(object={"env_var": env_var})
+    return env_var
+
+
 def get_brand_name(raise_if_not_found: bool = True,
                    raise_if_empty: bool = False) -> str:
     get_brand_name_result = our_get_env("BRAND_NAME",
@@ -296,19 +312,21 @@ def get_environment_name(raise_if_not_found: bool = True,
     return environment_name
 
 
-# TODO add optional_prefix optional parameter. First check with optional_prefix, if not found, check without it.
-def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True,
-                raise_if_empty: bool = False) -> str:
-    logger.start(object={"key": key, "default": default,
-                         "raise_if_not_found": raise_if_not_found,
-                         "raise_if_empty": raise_if_empty})
-    env_var = os.getenv(key, default)
-    # TODO: "default is None" is always False
-    if ((raise_if_not_found and key not in os.environ and default is None)
-            or (raise_if_empty and not env_var and not default)):
-        raise Exception(f"Environment variable {key} not found - please check your .env file")  # noqa: E501
-    logger.end(object={"env_var": env_var})
-    return env_var
+def get_product_user_identifier(raise_if_not_found: bool = True,
+                                raise_if_empty: bool = False) -> str:
+    get_product_user_identifier_result = our_get_env("PRODUCT_USER_IDENTIFIER",
+                                                     raise_if_not_found=raise_if_not_found,  # noqa E501
+                                                     raise_if_empty=raise_if_empty)  # noqa E501
+    return get_product_user_identifier_result
+
+
+def get_product_user_password(raise_if_not_found: bool = True,
+                              raise_if_empty: bool = False) -> str:
+    # TODO Add support to PRODUCT_USER_PASSWORD and deprecation message for PRODUCT_PASSWORD (backward compatible)
+    get_product_user_password_result = our_get_env("PRODUCT_PASSWORD",
+                                                     raise_if_not_found=raise_if_not_found,  # noqa E501
+                                                     raise_if_empty=raise_if_empty)  # noqa E501
+    return get_product_user_password_result
 
 
 # TODO As only the database package uses those, let's move those three to the database package  # noqa: E501
@@ -418,7 +436,7 @@ def validate_arguments(args: dict) -> None:
     :return: True if all arguments are not None or '', False otherwise
     """
     for arg, value in args.items():
-        if not arg:
+        if not value:
             raise ValueError(f"Argument {arg} is cannot be empty (got {value})")
 
 
@@ -464,7 +482,7 @@ def camel_to_snake(camel_str: str) -> str:
 def deprecation_warning_function(old_name: str, new_name: str, start_date: date = None) -> None:
     if start_date and start_date < date.today():
         return
-    warnings_message = f"Please use {old_name} instead of {new_name}."
+    warnings_message = f"Please use {new_name} instead of {old_name}."
     try:
         warnings_message += " Called from: " + inspect.stack()[2].filename
     except Exception:
